#! /usr/bin/env python
'''
Module Name:    EloTouchFwFlash.py

Description:    Class for Flashing Elo Touch FW Update

Copyright:      Toshiba Confidential

                OCO Source Materials

                Copyright (C) 2012,2013 Toshiba Global Commerce Solutions, Inc.

                The source code for this program is not published
                or otherwise divested of its trade secrets,
                irrespective of what has been deposited with the
                U. S. Copyright Office.

Initial Author: Francisco Liwa

Function:

Notes:

Dependencies:    None

Restrictions:    None

Last Modified: 30 September 2013
'''
import os

from monitorupgrade import TLog as TLOG
from monitorupgrade import Utils as utils
from monitorupgrade import Configs as Configs

EXIT_SUCCESS = 0
SAMPO_UTIL = '/opt/toshiba/mus/op_utils/sampo/4820MonUtil'
MUS_LOG_FILE_DIR = '/var/log/toshiba/mus/latest/'

#ELO Stuffs here    
ELO_DOWNLOAD = '/opt/toshiba/mus/op_utils/elo/EloDownload.sh'
ELO_CONFIG = '/opt/toshiba/mus/op_utils/elo/EloConfig.sh'
ELO_RECOVERY_FILE = '/opt/toshiba/mus/op_utils/elo/recovery.txt'

#==========================================================================================================
'''
TouchFwFlashTask_2Lx5Lx - Class for Flashing ELO 4820_2Lx5Lx Touch FW Update
'''
#==========================================================================================================
class TouchFwFlashTask_2Lx5Lx:
    fw_path=''
    fw_name=''
    controller=''
    
    def __init__(self,path,name,controller):
        '''
        Constructor
        '''
        #print 'Elo4820_2Lx5LxFlashTask Constructed'
        TLOG.logger.info('Elo4820_2Lx5LxFlashTask Constructed')
        self.fw_path = path
        self.fw_name = name
        self.controller = controller
        
    def run(self):       
        TLOG.logger.info('TouchFwFlashTask_2Lx5Lx::run() -----------------START---------------')
                
        fw_file_path = (os.path.join(self.fw_path ,self.fw_name))
        #print fw_file_path
        TLOG.logger.info('TouchFwFlashTask_2Lx5Lx::run() Locating firmware file : ' + fw_file_path)
        #eloDownloadCmd = 'sh ' +  ELO_DOWNLOAD + ' -select='+ self.controller +' -firmware_file=' + fw_file_path
        eloDownloadCmd = 'sh ' +  ELO_DOWNLOAD + ' -select=all  -firmware_file=' + fw_file_path
        
        if utils.doesFileExist(ELO_DOWNLOAD) != True:
            print '[TouchFwFlashTask_2Lx5Lx] - No ELO Download script found!'
            TLOG.logger.error('TouchFwFlashTask_2Lx5Lx::run()-No ELO Download script found!')
            raise IOError('No ELO Download script found!')
        else:
            print "[TouchFwFlashTask_2Lx5Lx] - This will take some time,Please wait ..."
            #elo_inventory_cmd = 'sh ' +  ELO_DOWNLOAD + ' -inventory'
            #ret = runSubprocess(elo_inventory_cmd,'ELODOWNLOAD-4820_2Lx5Lx')
            
            #make recovery text here
            rcv_text = 'EloRecover:' + ' ' +  fw_file_path
            f = open(ELO_RECOVERY_FILE,'w')
            f.write(rcv_text)
            f.close()           
            print "[TouchFwFlashTask_2Lx5Lx] - Starting update now..."
            ret = utils.runSubprocess(eloDownloadCmd,'ELODOWNLOAD-4820_2Lx5Lx')
        
        if ret != EXIT_SUCCESS:
            return ret #return immediately
        else:
            print '[Elo4820_2Lx5LxFlashTask] - Task Completed! - Please check log file at '  + MUS_LOG_FILE_DIR         
            TLOG.logger.info('Elo4820_2Lx5LxFlashTask::run() -----------------END-----------------\n')
            return ret
        

#==========================================================================================================
'''
TouchFwFlashTask_21x51x - Class for Flashing ELO 4820_21x51x Touch FW Update
'''
#==========================================================================================================        
class TouchFwFlashTask_21x51x:
    
    fw_path=''
    fw_name=''
    controller=''
    def __init__(self,path,name,controller):
        '''
        Constructor
        '''
        #print 'EloYamiFlashTask Constructed'
        TLOG.logger.info('TouchFwFlashTask_21x51x Constructed')
        self.fw_path = path
        self.fw_name = name
        self.controller = controller
        
    def run(self):    
        TLOG.logger.info('TouchFwFlashTask_21x51x::run() -----------------START---------------')
        
        fw_file_path = (os.path.join(self.fw_path ,self.fw_name))
        #print fw_file_path
        TLOG.logger.info('TouchFwFlashTask_21x51x::run() Locating firmware file : ' + fw_file_path)
        eloDownloadCmd = 'sh ' +  ELO_DOWNLOAD + ' -select=all -firmware_file=' + fw_file_path
                  
        if utils.doesFileExist(ELO_DOWNLOAD) != True:                      
            print '[TouchFwFlashTask_21x51x] - No ELO Download script found!'
            TLOG.logger.error('TouchFwFlashTask_21x51x::run()-No ELO Download script found!')
            raise IOError('No ELO Download script found!')
        else:
            print "[TouchFwFlashTask_21x51x] - This will take some time,Please wait ..."
            
            #make recovery text here
            rcv_text = 'EloRecover:' + ' ' +  fw_file_path
            f = open(ELO_RECOVERY_FILE,'w')
            f.write(rcv_text)
            print "[TouchFwFlashTask_21x51x] - Starting update now..."
            ret = utils.runSubprocess(eloDownloadCmd,'ELODOWNLOAD-4820_21x51x')      
        if ret != EXIT_SUCCESS:
            return ret #return immediately
        else:            
            print '[TouchFwFlashTask_21x51x] - Task Completed! - Please check log file at '  + MUS_LOG_FILE_DIR
            TLOG.logger.info('TouchFwFlashTask_21x51x::run() -----------------END-----------------\n')
            return ret
        
        
#==========================================================================================================
'''
ConfigTask - Do all stuffs here that uses ELO Config Utility 
'''
#==========================================================================================================
class ConfigTask:
    def __init__(self):
        '''
        Constructor
        '''
        #print 'EloConfigTask Constructed'
        TLOG.logger.info('EloConfigTask Constructed!')
    
    def run(self):        
        TLOG.logger.info('EloConfigTask::run() -----------------START---------------')
        
        elo_config = Configs.EloUtilityConfig()      
              
        TLOG.logger.debug('EloConfigTask::run() -Dumping configuration file... ')
        TLOG.logger.info('EloConfigTask::run()-================================ Running ELO Config Utility =================================')
        TLOG.logger.info('EloConfigTask::run()- Updating...')
        
        print "[EloConfigTask] - Starting Touch Configuration update now..." 
        print "[EloConfigTask] - This will take some time,Please wait ..." 
        eloconfig_inventory_cmd = 'sh ' + ELO_CONFIG + ' -INVENTORY' 
        ret = utils.runSubprocess(eloconfig_inventory_cmd,'ELOCONFIGUTILITY')
        if ret != EXIT_SUCCESS:
            return ret #return immediately
        
        for option in elo_config.options:
            
            if option == 'uit': 
                TLOG.logger.info('EloConfigTask::run()- Updating uit...')
                value = elo_config.getEloOptionValue(option)
                eloConfigCommand = 'sh ' + ELO_CONFIG + ' -SELECT=ALL -SET_UIT_LEVEL=' + str(value) 
                #ret = runSubprocess(eloConfigCommand,'ELOCONFIGUTILITY')
            
            elif option == 'beepfreq':
                
                TLOG.logger.info('EloConfigTask::run()- Updating beep freq...')
                value = elo_config.getEloOptionValue(option)
                eloConfigCommand = 'sh ' + ELO_CONFIG + ' -SELECT=ALL -SET_BEEP_FREQUENCY=' + value
                #ret = runSubprocess(eloConfigCommand,'ELOCONFIGUTILITY')
                
            elif option == 'beepmode':
                
                TLOG.logger.info('EloConfigTask::run()- Updating beep mode...')
                value = elo_config.getEloOptionValue(option)
                eloConfigCommand = 'sh ' + ELO_CONFIG + ' -SELECT=ALL -SET_BEEP_MODE=' + str(value)
                #ret = runSubprocess(eloConfigCommand,'ELOCONFIGUTILITY')
            
            elif option == 'beeptime':
                
                TLOG.logger.info('EloConfigTask::run()- Updating beep duration...')
                value = elo_config.getEloOptionValue(option)
                eloConfigCommand = 'sh ' + ELO_CONFIG + ' -SELECT=ALL -SET_BEEP_DURATION=' + value
                #ret = runSubprocess(eloConfigCommand,'ELOCONFIGUTILITY')
            
            elif option == 'tone':
                
                TLOG.logger.info('EloConfigTask::run()- Updating tone mode...')
                value = elo_config.getEloOptionValue(option)
                eloConfigCommand = 'sh '+ ELO_CONFIG + ' -SELECT=ALL -SET_TONE_MODE=' + value
            
            # @TODO: add more options to update here
                    
            else:            
                eloConfigCommand = 'sh '+ ELO_CONFIG + '-DESCRIBE' 
                            
            ret = utils.runSubprocess(eloConfigCommand,'ELOCONFIGUTILITY')
            
        #Check if values are updated
        ret = utils.runSubprocess(eloconfig_inventory_cmd,'ELOCONFIGUTILITY')
            
        if ret != EXIT_SUCCESS:           
            return ret #return immediately
        else:
            print '[EloConfigTask] - Task Completed! - Please check log file at '  + MUS_LOG_FILE_DIR
            TLOG.logger.info('EloConfigTask::run() -----------------END-----------------\n')     
            return ret          
        
##==========================================================================================================
#TouchFwRecoveryFlashTask - Class for the Sampo Recovery Task for Video Flash
##==========================================================================================================        
class TouchFwRecoveryFlashTask:
    def __init__(self):
        '''
        Constructor
        '''
        #print 'SampoVideoFlashRecoveryTask Constructed'
        TLOG.logger.info('EloTouchFlashRecoveryTask Constructed')
    
          
    def run(self,fw_path):
        TLOG.logger.info('EloTouchFlashRecoveryTask::run()-----------------START---------------')
        
        ret = utils.doEloRecover(fw_path)
        print 'EloTouchFlashRecoveryTas Done.' + '{' + str(ret) + '}'
        
        TLOG.logger.info('EloTouchFlashRecoveryTask::run() - Deleting Elo Recovery file.' )
        utils.runShell('rm ' + ELO_RECOVERY_FILE)
        
        TLOG.logger.info('EloTouchFlashRecoveryTask::run()-----------------END-----------------\n')
        print 'System is rebooting now...'
        utils.runShell('reboot')
        
        #return EXIT_SUCCESS