'''
Module Name:    TLog.py

Description:    This is the logger for MUS.

Copyright:      Toshiba Confidential

                OCO Source Materials

                Copyright (C) 2012,2013 Toshiba Global Commerce Solutions, Inc.

                The source code for this program is not published
                or otherwise divested of its trade secrets,
                irrespective of what has been deposited with the
                U. S. Copyright Office.

Initial Author: Francisco Liwa

Function:

Notes:

Dependencies:    None

Restrictions:    None

Created: October 3, 2012

'''


'''
LOG LEVELS

    -DEBUG
    -INFO
    -WARNING
    -ERROR
    -CRITICAL

'''

import logging
import os,subprocess
import datetime
from os.path import join, getsize

VER= 3
MUS_LOG_FILE_DIR = '/var/log/toshiba/mus/latest'
MUS_LOG_HISTORY_DIR = '/var/log/toshiba/mus/history'
LOG_NAME = 'MUS-v1.1'
MAX_LOG_HISTORY_COUNT = 10
LOG_VER='[' + LOG_NAME + '-' + str(VER) + ']'
        

#clean log directory first
if os.path.exists(MUS_LOG_FILE_DIR):
    
    if os.path.exists(MUS_LOG_HISTORY_DIR):
        for root, dirs, files in os.walk(MUS_LOG_HISTORY_DIR,topdown=True):
            count = len(files)
            files.sort()          
            if(count == MAX_LOG_HISTORY_COUNT):     # We only store log file history until MAX_LOG_HISTORY_COUNT
                #print 'WARNING! Maximum count reached'
                #print files[0]              
                log = str(root)+ '/' + str( files[0] ) 
                #print 'log is =' , log
                cmd = 'rm ' + ' ' + log
                process = subprocess.Popen(cmd,shell=True)      #deleting the oldest log file
                process.wait()                 
    else:    
        cmd = 'mkdir' + ' ' + MUS_LOG_HISTORY_DIR  
        process = subprocess.Popen(cmd,shell=True)
        process.wait()
        
    #transferring the recent log file to history
    for root, dirs, files in os.walk(MUS_LOG_FILE_DIR,topdown=True):
        count = len(files)
        files.sort()
        for logfile in files:
            logname = join(root,logfile)
            #print logname 
              
            filesize = getsize(logname)
            #print filesize
            
            if  filesize == 0:
                cmd = 'rm ' + str(logname)       
                process = subprocess.Popen(cmd,shell=True)
                process.wait()
            else:                   
                cmd = 'mv ' + str(logname) + ' ' +  MUS_LOG_HISTORY_DIR            
                process = subprocess.Popen(cmd,shell=True)
                process.wait()
        
else:
    cmd = 'mkdir' + ' ' + MUS_LOG_FILE_DIR  
    process = subprocess.Popen(cmd,shell=True)
    process.wait()
    
            

#Create the logger object
logger = logging.getLogger(LOG_VER)
#logger.setLevel(logging.INFO)
logger.setLevel(logging.INFO)  

# make some handlers
date_now = datetime.datetime.now()
date_,time_ = str(date_now).split(' ')

name = LOG_NAME + '-' + str( date_ ) + '_' +str( time_ ) + '.log'

logname = os.path.join(MUS_LOG_FILE_DIR,name)
#print 'Logging to file '+ name
console_handler = logging.StreamHandler() # by default, sys.stderr
file_handler = logging.FileHandler(logname)


# set logging levels
console_handler.setLevel(logging.WARNING)
#file_handler.setLevel(logging.INFO)
file_handler.setLevel(logging.DEBUG)

# create formatter
formatter = logging.Formatter('%(asctime)s - %(name)s:[%(levelname)s] - %(message)s')

# add formatter to file_handler
file_handler.setFormatter(formatter)
console_handler.setFormatter(formatter)
  
# add handlers to logger
logger.addHandler(console_handler)
logger.addHandler(file_handler)      
        
        
            
        
